@@ -23,13 +23,15 @@ func (o Options) Run() error {
 		selectedStyle:   o.SelectedStyle.ToLipgloss(),
 		unselectedStyle: o.UnselectedStyle.ToLipgloss(),
 		promptStyle:     o.PromptStyle.ToLipgloss(),
-	}, tea.WithOutput(os.Stderr)).StartReturningModel()
+	}, tea.WithOutput(os.Stderr)).Run()
 
 	if err != nil {
 		return fmt.Errorf("unable to run confirm: %w", err)
 	}
 
-	if m.(model).confirmation {
+	if m.(model).aborted {
+		os.Exit(130)
+	} else if m.(model).confirmation {
 		os.Exit(0)
 	} else {
 		os.Exit(1)
