@@ -37,10 +37,12 @@ func (o Options) Run() error {
 	}
 
 	p := tea.NewProgram(model{
-		textinput: i,
-		aborted:   false,
+		textinput:   i,
+		aborted:     false,
+		header:      o.Header,
+		headerStyle: o.HeaderStyle.ToLipgloss(),
 	}, tea.WithOutput(os.Stderr))
-	tm, err := p.StartReturningModel()
+	tm, err := p.Run()
 	if err != nil {
 		return fmt.Errorf("failed to run input: %w", err)
 	}
